| realCloneData | R Documentation |
42 clones (39 distinct) from 32 individual donors, 13 of whom have a diagnosis of Myeloproliferative Neoplasm
data(realCloneData)
A list of containing one list with the full ultrametric
trees from 30 of the 32 individual donors (the two from Van Egeren are not included),
and one list containing the 42 clone trees.In three cases, there are two
timepoints from the same clone, and these are separate phylo objects.
Each list contains a tree as a class phylo object.
See ape package documentation for details on class phylo objects.
Names of each phylo object (tree) in the list matches the naming used
in the sources and also includes driver, age, and clone number.
These datasets were generated and annotated in: Williams et al. 2022 Mitchell et al. 2022 Fabre et al. 2022 Van Egeren et al. 2021
# Plot full reconstructed tree from donor PD34493
ape::plot.phylo(cloneRate::realCloneData[["fullTrees"]][["PD34493"]],
direction = "downwards", show.tip.label = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.